From: Jeremy Evans Date: 2010-08-11T00:45:32+09:00 Subject: [ruby-core:31665] [Feature #3667] Speedup Date._parse and Date._strptime by using a Hash instead of a Date::Format::Bag Issue #3667 has been updated by Jeremy Evans. Tadayoshi Funaba, Did you do any testing to see how the use of Struct affects performance? In my testing, while your use of Struct provides a modest speedup over the previous code, it's nowhere near as much of a speedup as using a plain hash. $ ruby -v ruby 1.9.2dev (2010-07-11 revision 28618) [x86_64-openbsd4.7] Date._parse: $ time ruby date_parse.rb real 0m1.222s user 0m1.180s sys 0m0.040s $ time ruby -I date-struct date_parse.rb real 0m1.152s user 0m1.060s sys 0m0.090s $ time ruby -I date-hash date_parse.rb real 0m0.805s user 0m0.740s sys 0m0.060s Date._strptime: $ time ruby date_strptime.rb real 0m2.023s user 0m1.990s sys 0m0.030s $ time ruby -I date-struct date_strptime.rb real 0m1.974s user 0m1.950s sys 0m0.020s $ time ruby -I date-hash date_strptime.rb real 0m1.611s user 0m1.580s sys 0m0.030s Please consider reverting your Struct commit (#28953) and committing my patch for a plain hash. Thank you, Jeremy Evans ---------------------------------------- http://redmine.ruby-lang.org/issues/show/3667 ---------------------------------------- http://redmine.ruby-lang.org